@@ -19,23 +19,41 @@ package client_test
 
 import (
 	"context"
+	"fmt"
+	"math/rand"
 	"testing"
 
 	"github.com/apache/servicecomb-service-center/client"
 	"github.com/apache/servicecomb-service-center/pkg/rpc"
 	v1sync "github.com/apache/servicecomb-service-center/syncer/api/v1"
+	syncrpc "github.com/apache/servicecomb-service-center/syncer/rpc"
 	"github.com/stretchr/testify/assert"
 )
 
+type mockServer struct {
+	v1sync.UnimplementedEventServiceServer
+}
+
+func (s *mockServer) Sync(ctx context.Context, events *v1sync.EventList) (*v1sync.Results, error) {
+	return &v1sync.Results{}, nil
+}
+
 func TestNewSetForConfig(t *testing.T) {
+	port := 30101 + rand.Intn(1000)
+	addr := fmt.Sprintf("127.0.0.1:%d", port)
+
+	server := syncrpc.MockServer(addr, &mockServer{})
+	defer server.Stop()
+
 	conn, err := rpc.GetPickFirstLbConn(
 		&rpc.Config{
-			Addrs:       []string{"127.0.0.1:30105"},
+			Addrs:       []string{addr},
 			Scheme:      "test",
 			ServiceName: "serviceName",
 		})
 	assert.NoError(t, err)
 	defer conn.Close()
+
 	set := client.NewSet(conn)
 	_, err = set.EventServiceClient.Sync(context.TODO(), &v1sync.EventList{Events: []*v1sync.Event{
 		{Action: "create"},
