@@ -18,10 +18,6 @@
 package main
 
 import (
-	"context"
-
-	_ "github.com/apache/servicecomb-service-center/syncer/init"
-
 	_ "github.com/apache/servicecomb-service-center/server/init"
 
 	_ "github.com/apache/servicecomb-service-center/syncer/bootstrap"
@@ -30,12 +26,9 @@ import (
 
 	"github.com/apache/servicecomb-service-center/server"
 	syncsvr "github.com/apache/servicecomb-service-center/syncer/server"
-	"github.com/go-chassis/foundation/gopool"
 )
 
 func main() {
-	gopool.Go(func(_ context.Context) {
-		syncsvr.Run()
-	})
+	syncsvr.Run()
 	server.Run()
 }
