@@ -19,17 +19,12 @@ package datasource
 
 import (
 	"context"
-	"time"
 
-	"github.com/apache/servicecomb-service-center/pkg/cluster"
+	"github.com/little-cui/etcdadpt"
 )
 
 // SCManager contains the APIs of registration of SC itself
 type SCManager interface {
-	SelfRegister(ctx context.Context) error
-	SelfUnregister(ctx context.Context) error
-	// OPS
-	ClearNoInstanceServices(ctx context.Context, ttl time.Duration) error
 	UpgradeVersion(ctx context.Context) error
-	GetClusters(ctx context.Context) (cluster.Clusters, error)
+	GetClusters(ctx context.Context) (etcdadpt.Clusters, error)
 }
