@@ -25,6 +25,7 @@ import (
 	"strconv"
 	"time"
 
+	"github.com/apache/servicecomb-service-center/syncer/service/event"
 	pb "github.com/go-chassis/cari/discovery"
 	"github.com/go-chassis/cari/pkg/errsvc"
 	"github.com/go-chassis/cari/sync"
@@ -38,19 +39,18 @@ import (
 	"github.com/apache/servicecomb-service-center/datasource/etcd/state/kvstore"
 	esync "github.com/apache/servicecomb-service-center/datasource/etcd/sync"
 	eutil "github.com/apache/servicecomb-service-center/datasource/etcd/util"
+	serviceUtil "github.com/apache/servicecomb-service-center/datasource/etcd/util"
 	"github.com/apache/servicecomb-service-center/datasource/schema"
 	"github.com/apache/servicecomb-service-center/pkg/log"
 	"github.com/apache/servicecomb-service-center/pkg/util"
 	"github.com/apache/servicecomb-service-center/server/core"
 	"github.com/apache/servicecomb-service-center/server/plugin/uuid"
 	quotasvc "github.com/apache/servicecomb-service-center/server/service/quota"
-	"github.com/apache/servicecomb-service-center/syncer/service/event"
 )
 
 type MetadataManager struct {
 	// InstanceTTL options
-	InstanceTTL        int64
-	InstanceProperties map[string]string
+	InstanceTTL int64
 }
 
 // RegisterService implement:
@@ -186,92 +186,6 @@ func (ds *MetadataManager) GetService(ctx context.Context, request *pb.GetServic
 	return singleService, nil
 }
 
-func (ds *MetadataManager) ListServiceDetail(ctx context.Context, request *pb.GetServicesInfoRequest) (
-	*pb.GetServicesInfoResponse, error) {
-	ctx = util.WithCacheOnly(ctx)
-
-	optionMap := make(map[string]struct{}, len(request.Options))
-	for _, opt := range request.Options {
-		optionMap[opt] = struct{}{}
-	}
-
-	options := make([]string, 0, len(optionMap))
-	if _, ok := optionMap["all"]; ok {
-		optionMap["statistics"] = struct{}{}
-		options = []string{"tags", "instances", "schemas", "dependencies"}
-	} else {
-		for opt := range optionMap {
-			options = append(options, opt)
-		}
-	}
-
-	var st *pb.Statistics
-	if _, ok := optionMap["statistics"]; ok {
-		var err error
-		st, err = statistics(ctx, request.WithShared)
-		if err != nil {
-			return nil, pb.NewError(pb.ErrInternal, err.Error())
-		}
-		if len(optionMap) == 1 {
-			return &pb.GetServicesInfoResponse{
-				Statistics: st,
-			}, nil
-		}
-	}
-
-	//获取所有服务
-	services, err := eutil.GetAllServiceUtil(ctx)
-	if err != nil {
-		log.Error("get all services by domain failed", err)
-		return nil, pb.NewError(pb.ErrInternal, err.Error())
-	}
-
-	allServiceDetails := make([]*pb.ServiceDetail, 0, len(services))
-	domainProject := util.ParseDomainProject(ctx)
-	for _, service := range services {
-		if !ds.filterServices(domainProject, request, service) {
-			continue
-		}
-
-		serviceDetail, err := getServiceDetailUtil(ctx, ServiceDetailOpt{
-			domainProject: domainProject,
-			service:       service,
-			countOnly:     request.CountOnly,
-			options:       options,
-		})
-		if err != nil {
-			return nil, pb.NewError(pb.ErrInternal, err.Error())
-		}
-		serviceDetail.MicroService = service
-		tmpServiceDetail, err := datasource.NewServiceOverview(serviceDetail, ds.InstanceProperties)
-		if err != nil {
-			return nil, err
-		}
-		allServiceDetails = append(allServiceDetails, tmpServiceDetail)
-	}
-
-	return &pb.GetServicesInfoResponse{
-		AllServicesDetail: allServiceDetails,
-		Statistics:        st,
-	}, nil
-}
-
-func (ds *MetadataManager) filterServices(domainProject string, request *pb.GetServicesInfoRequest, service *pb.MicroService) bool {
-	if !request.WithShared && datasource.IsGlobal(pb.MicroServiceToKey(domainProject, service)) {
-		return false
-	}
-	if len(request.Environment) > 0 && request.Environment != service.Environment {
-		return false
-	}
-	if len(request.AppId) > 0 && request.AppId != service.AppId {
-		return false
-	}
-	if len(request.ServiceName) > 0 && request.ServiceName != service.ServiceName {
-		return false
-	}
-	return true
-}
-
 func (ds *MetadataManager) GetOverview(ctx context.Context, request *pb.GetServicesRequest) (
 	*pb.Statistics, error) {
 	ctx = util.WithCacheOnly(ctx)
@@ -1652,3 +1566,59 @@ func (ds *MetadataManager) UnregisterService(ctx context.Context, request *pb.De
 	log.Info(fmt.Sprintf("%s micro-service[%s] successfully, operator: %s", title, serviceID, remoteIP))
 	return nil
 }
+
+func (ds *MetadataManager) Statistics(ctx context.Context, withShared bool) (*pb.Statistics, error) {
+	return statistics(ctx, withShared)
+}
+
+func (ds *MetadataManager) UpdateManyInstanceStatus(ctx context.Context, match *datasource.MatchPolicy, status string) error {
+	resp, _ := ds.ListManyInstances(ctx, &pb.GetAllInstancesRequest{})
+	instances := resp.Instances
+	if len(instances) == 0 {
+		return nil
+	}
+	options := make([]etcdadpt.OpOptions, 0)
+	cmps := make([]etcdadpt.CmpOptions, 0)
+
+	domainProject := util.ParseDomainProject(ctx)
+
+	for _, instance := range instances {
+		var t = true
+		for k, v := range match.Properties {
+			value, ok := instance.Properties[k]
+			if ok {
+				if value != v {
+					t = false
+					break
+				}
+			} else {
+				t = false
+				break
+			}
+		}
+		if t {
+			key := path.GenerateInstanceKey(domainProject, instance.ServiceId, instance.InstanceId)
+			//更新状态
+			instance.Status = status
+			data, _ := json.Marshal(instance)
+			leaseID, err := serviceUtil.GetLeaseID(ctx, domainProject, instance.ServiceId, instance.InstanceId)
+			if err != nil {
+				log.Error(fmt.Sprintf("get leaseId %s error", instance.InstanceId), err)
+				continue
+			}
+			options = append(options, etcdadpt.Ops(etcdadpt.OpPut(etcdadpt.WithStrKey(key), etcdadpt.WithValue(data), etcdadpt.WithLease(leaseID)))...)
+			cmps = append(cmps, etcdadpt.If(etcdadpt.NotEqualVer(path.GenerateServiceKey(domainProject, instance.ServiceId), 0))...)
+		}
+	}
+	_, err := etcdadpt.TxnWithCmp(ctx,
+		options,
+		cmps,
+		nil)
+
+	if err != nil {
+		log.Error("UpdateManyInstanceStatus error", err)
+
+		return pb.NewError(pb.ErrUnavailableBackend, err.Error())
+	}
+	return nil
+}
