@@ -20,13 +20,13 @@ package util
 import (
 	"context"
 
-	"github.com/apache/servicecomb-service-center/datasource/etcd/client"
-	"github.com/apache/servicecomb-service-center/datasource/etcd/kv"
+	"github.com/apache/servicecomb-service-center/datasource/etcd/sd"
+	"github.com/little-cui/etcdadpt"
 )
 
 func CheckSchemaInfoExist(ctx context.Context, key string) (bool, error) {
-	opts := append(FromContext(ctx), client.WithStrKey(key), client.WithCountOnly())
-	resp, errDo := kv.Store().Schema().Search(ctx, opts...)
+	opts := append(FromContext(ctx), etcdadpt.WithStrKey(key), etcdadpt.WithCountOnly())
+	resp, errDo := sd.Schema().Search(ctx, opts...)
 	if errDo != nil {
 		return false, errDo
 	}
