@@ -22,12 +22,13 @@ import (
 	"testing"
 	"time"
 
+	heartbeatcache "github.com/apache/servicecomb-service-center/datasource/mongo/heartbeat/cache"
+
 	"github.com/go-chassis/cari/db/mongo"
 	pb "github.com/go-chassis/cari/discovery"
 	"github.com/stretchr/testify/assert"
 	"go.mongodb.org/mongo-driver/bson"
 
-	"github.com/apache/servicecomb-service-center/datasource/mongo/heartbeat/cache"
 	"github.com/apache/servicecomb-service-center/datasource/mongo/model"
 	"github.com/apache/servicecomb-service-center/datasource/mongo/util"
 	_ "github.com/apache/servicecomb-service-center/test"
