@@ -18,15 +18,30 @@
 package datasource
 
 import (
-	"github.com/little-cui/etcdadpt"
+	"crypto/tls"
+	"time"
+
+	"github.com/go-chassis/openlog"
 )
 
-//Options contains configuration for plugins
+// Options contains configuration for plugins
 type Options struct {
-	etcdadpt.Config
+	// Kind plugin kind, can be 'etcd' or 'mongo'
+	Kind string `json:"-"`
+	// Logger logger for adapter, by default use openlog.GetLogger()
+	Logger     openlog.Logger `json:"-"`
+	SslEnabled bool           `json:"-"`
+	TLSConfig  *tls.Config    `json:"-"`
+	// ErrorFunc called when connection error occurs
+	ErrorFunc func(err error) `json:"-"`
+	// ConnectedFunc called when connected
+	ConnectedFunc func() `json:"-"`
+
+	// CompactInterval optional, compact backend
+	CompactInterval   time.Duration `json:"-"`
+	CompactIndexDelta int64         `json:"-"`
 
 	EnableCache bool
 	// InstanceTTL: the default ttl of instance lease
-	InstanceTTL        int64
-	InstanceProperties map[string]string
+	InstanceTTL int64
 }
