@@ -18,6 +18,8 @@
 package chain
 
 import (
+	"fmt"
+
 	"github.com/apache/servicecomb-service-center/pkg/log"
 	"github.com/apache/servicecomb-service-center/pkg/util"
 )
@@ -39,7 +41,7 @@ func RegisterHandler(catalog string, h Handler) {
 	handlersMap[catalog] = handlers
 
 	t := util.Reflect(h)
-	log.Infof("register chain handler[%s] %s", catalog, t.Name())
+	log.Info(fmt.Sprintf("register chain handler[%s] %s", catalog, t.Name()))
 }
 
 func Handlers(catalog string) []Handler {
