@@ -20,7 +20,7 @@ import (
 	"testing"
 	"time"
 
-	"github.com/astaxie/beego"
+	beego "github.com/beego/beego/v2/server/web"
 )
 
 func TestInstanceName(t *testing.T) {
