@@ -18,11 +18,25 @@
 package util
 
 import (
+	"bytes"
 	"runtime"
 	"strings"
 	"unsafe"
+
+	"github.com/cloudflare/gokey"
 )
 
+const TypePass = "pass"
+
+var passwordSpec = &gokey.PasswordSpec{
+	Length:         8,
+	Upper:          1,
+	Lower:          1,
+	Digits:         1,
+	Special:        1,
+	AllowedSpecial: "-~!@#$%^&*()_=+|<>{}[]",
+}
+
 func SafeCloseChan(c chan struct{}) {
 	if c == nil {
 		return
@@ -146,3 +160,37 @@ func ToDomainProject(domain, project string) (domainProject string) {
 func IsVersionOrHealthPattern(pattern string) bool {
 	return strings.HasSuffix(pattern, "/version") || strings.HasSuffix(pattern, "/health")
 }
+
+func ToSnake(name string) string {
+	if name == "" {
+		return ""
+	}
+	temp := strings.Split(name, "-")
+	var buffer bytes.Buffer
+	for num, v := range temp {
+		vv := []rune(v)
+		if num == 0 {
+			buffer.WriteString(string(vv))
+			continue
+		}
+		if len(vv) > 0 {
+			if vv[0] >= 'a' && vv[0] <= 'z' { //首字母大写
+				vv[0] -= 32
+			}
+			buffer.WriteString(string(vv))
+		}
+	}
+	return buffer.String()
+}
+
+func GeneratePassword() (string, error) {
+	seed, err := gokey.GenerateEncryptedKeySeed(TypePass)
+	if err != nil {
+		return "", err
+	}
+	pass, err := gokey.GetPass(TypePass, "", seed, passwordSpec)
+	if err != nil {
+		return "", err
+	}
+	return pass, nil
+}
