@@ -19,7 +19,7 @@ package etcd
 
 import (
 	"crypto/tls"
-	"io/ioutil"
+	"os"
 	"strings"
 	"time"
 
@@ -31,12 +31,12 @@ import (
 func NewEtcdClient(cfg Config) (*clientv3.Client, error) {
 	var (
 		endpoints = strings.Split(cfg.Addrs, ",")
-		cliTls    *tls.Config
+		cliTLS    *tls.Config
 	)
 	for _, ip := range endpoints {
 		if strings.Contains(ip, "https://") {
 			if len(cfg.CertKeyPWD) == 0 && len(cfg.CertKeyPWDPath) > 0 {
-				content, _ := ioutil.ReadFile(cfg.CertKeyPWDPath)
+				content, _ := os.ReadFile(cfg.CertKeyPWDPath)
 				cfg.CertKeyPWD = string(content)
 			}
 			opts := append(tlsutil.DefaultClientTLSOptions(),
@@ -44,7 +44,7 @@ func NewEtcdClient(cfg Config) (*clientv3.Client, error) {
 				tlsutil.WithCert(cfg.CertFile),
 				tlsutil.WithKey(cfg.CertKeyFile),
 				tlsutil.WithKeyPass(cfg.CertKeyPWD))
-			cliTls, _ = tlsutil.GetClientTLSConfig(opts...)
+			cliTLS, _ = tlsutil.GetClientTLSConfig(opts...)
 			break
 		}
 	}
@@ -52,7 +52,7 @@ func NewEtcdClient(cfg Config) (*clientv3.Client, error) {
 	client, err := clientv3.New(clientv3.Config{
 		Endpoints:   endpoints,
 		DialTimeout: 10 * time.Second,
-		TLS:         cliTls,
+		TLS:         cliTLS,
 	})
 	if err != nil {
 		return nil, err
