@@ -21,7 +21,6 @@ import (
 	"context"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strings"
@@ -41,7 +40,7 @@ import (
 )
 
 var (
-	AppId       string
+	AppID       string
 	ServiceName string
 	Version     string
 	SaveDir     string
@@ -55,12 +54,12 @@ func NewSchemaCommand(parent *cobra.Command) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "schema [options]",
 		Short: "Output the microservice schema information of the service center ",
-		Run:   SchemaCommandFunc,
+		Run:   CommandFunc,
 	}
 
 	cmd.Flags().StringVarP(&SaveDir, "save-dir", "s", "",
 		"the directory to save the schemas data")
-	cmd.Flags().StringVar(&AppId, "app", "", "the application name of microservice")
+	cmd.Flags().StringVar(&AppID, "app", "", "the application name of microservice")
 	cmd.Flags().StringVar(&ServiceName, "name", "", "the name of microservice")
 	cmd.Flags().StringVar(&Version, "version", "", "the semantic version of microservice")
 
@@ -83,7 +82,7 @@ func saveDirectory(root string, ms *dump.Microservice) string {
 	return filepath.Join(root, "schemas", domain, project, ms.Value.Environment, ms.Value.AppId, ms.Value.ServiceName+".v"+ms.Value.Version)
 }
 
-func SchemaCommandFunc(_ *cobra.Command, args []string) {
+func CommandFunc(_ *cobra.Command, args []string) {
 	scClient, err := client.NewSCClient(cmd.ScClientConfig)
 	if err != nil {
 		cmd.StopAndExit(cmd.ExitError, err)
@@ -95,7 +94,7 @@ func SchemaCommandFunc(_ *cobra.Command, args []string) {
 
 	var progressBarWriter io.Writer = os.Stdout
 	if len(SaveDir) == 0 {
-		progressBarWriter = ioutil.Discard
+		progressBarWriter = io.Discard
 	}
 	progressBar := pb.NewProgressBar(len(cache.Microservices), progressBarWriter)
 	defer progressBar.FinishPrint("Finished.")
@@ -107,7 +106,7 @@ func SchemaCommandFunc(_ *cobra.Command, args []string) {
 		if !get.AllDomains && strings.Index(domainProject+path.SPLIT, get.Domain+path.SPLIT) != 0 {
 			continue
 		}
-		if len(AppId) > 0 && ms.Value.AppId != AppId {
+		if len(AppID) > 0 && ms.Value.AppId != AppID {
 			continue
 		}
 		if len(ServiceName) > 0 && ms.Value.ServiceName != ServiceName {
