@@ -31,15 +31,15 @@ var (
 	shortServiceTableHeader  = []string{"NAME", "APPID", "VERSIONS", "ENV", "FRAMEWORK", "AGE"}
 )
 
-type ServiceRecord struct {
+type Record struct {
 	model.Service
 }
 
-func (s *ServiceRecord) VersionsString() string {
+func (s *Record) VersionsString() string {
 	return util.StringJoin(s.Versions, "\n")
 }
 
-func (s *ServiceRecord) FrameworksString() string {
+func (s *Record) FrameworksString() string {
 	var arr []string
 	for _, fw := range s.Frameworks {
 		arr = append(arr, fw.Name)
@@ -47,57 +47,57 @@ func (s *ServiceRecord) FrameworksString() string {
 	return util.StringJoin(arr, "\n")
 }
 
-func (s *ServiceRecord) EndpointsString() string {
+func (s *Record) EndpointsString() string {
 	return util.StringJoin(s.Endpoints, "\n")
 }
 
-func (s *ServiceRecord) AgeString() string {
+func (s *Record) AgeString() string {
 	return writer.TimeFormat(s.Age())
 }
 
-func (s *ServiceRecord) Domain() string {
+func (s *Record) Domain() string {
 	domain, _ := util.FromDomainProject(s.DomainProject)
 	return domain
 }
 
-func (s *ServiceRecord) PrintBody(fmt string, all bool) []string {
+func (s *Record) PrintBody(fmt string, all bool) []string {
 	switch {
 	case fmt == "wide":
-		return []string{s.Domain(), s.ServiceName, s.AppId, s.VersionsString(), s.Environment,
+		return []string{s.Domain(), s.ServiceName, s.AppID, s.VersionsString(), s.Environment,
 			s.FrameworksString(), s.EndpointsString(), s.AgeString()}
 	case all:
-		return writer.Reshape(maxWidth, []string{s.Domain(), s.ServiceName, s.AppId,
+		return writer.Reshape(maxWidth, []string{s.Domain(), s.ServiceName, s.AppID,
 			s.VersionsString(), s.Environment, s.FrameworksString(), s.AgeString()})
 	default:
-		return writer.Reshape(maxWidth, []string{s.ServiceName, s.AppId,
+		return writer.Reshape(maxWidth, []string{s.ServiceName, s.AppID,
 			s.VersionsString(), s.Environment, s.FrameworksString(), s.AgeString()})
 	}
 }
 
-type ServicePrinter struct {
-	Records map[string]*ServiceRecord
+type Printer struct {
+	Records map[string]*Record
 	flags   []interface{}
 }
 
-func (sp *ServicePrinter) SetOutputFormat(f string, all bool) {
+func (sp *Printer) SetOutputFormat(f string, all bool) {
 	sp.Flags(f, all)
 }
 
-func (sp *ServicePrinter) Flags(flags ...interface{}) []interface{} {
+func (sp *Printer) Flags(flags ...interface{}) []interface{} {
 	if len(flags) > 0 {
 		sp.flags = flags
 	}
 	return sp.flags
 }
 
-func (sp *ServicePrinter) PrintBody() (slice [][]string) {
+func (sp *Printer) PrintBody() (slice [][]string) {
 	for _, s := range sp.Records {
 		slice = append(slice, s.PrintBody(sp.flags[0].(string), sp.flags[1].(bool)))
 	}
 	return
 }
 
-func (sp *ServicePrinter) PrintTitle() []string {
+func (sp *Printer) PrintTitle() []string {
 	switch {
 	case sp.flags[0] == "wide":
 		return longServiceTableHeader
@@ -108,6 +108,6 @@ func (sp *ServicePrinter) PrintTitle() []string {
 	}
 }
 
-func (sp *ServicePrinter) Sorter() *writer.RecordsSorter {
+func (sp *Printer) Sorter() *writer.RecordsSorter {
 	return nil
 }
