@@ -40,14 +40,14 @@ func NewServiceCommand(parent *cobra.Command) *cobra.Command {
 		Use:     "service [options]",
 		Aliases: []string{"svc"},
 		Short:   "Output the microservice information of the service center ",
-		Run:     ServiceCommandFunc,
+		Run:     CommandFunc,
 	}
 
 	parent.AddCommand(cmd)
 	return cmd
 }
 
-func ServiceCommandFunc(_ *cobra.Command, args []string) {
+func CommandFunc(_ *cobra.Command, args []string) {
 	scClient, err := client.NewSCClient(cmd.ScClientConfig)
 	if err != nil {
 		cmd.StopAndExit(cmd.ExitError, err)
@@ -59,11 +59,11 @@ func ServiceCommandFunc(_ *cobra.Command, args []string) {
 
 	endpointMap := make(map[string][]string)
 	for i := 0; i < len(cache.Instances); i++ {
-		serviceId := cache.Instances[i].Value.ServiceId
-		endpointMap[serviceId] = append(endpointMap[serviceId], cache.Instances[i].Value.Endpoints...)
+		serviceID := cache.Instances[i].Value.ServiceId
+		endpointMap[serviceID] = append(endpointMap[serviceID], cache.Instances[i].Value.Endpoints...)
 	}
 
-	records := make(map[string]*ServiceRecord)
+	records := make(map[string]*Record)
 	for _, ms := range cache.Microservices {
 		domainProject := model.GetDomainProject(ms)
 		if !get.AllDomains && strings.Index(domainProject+path.SPLIT, get.Domain+path.SPLIT) != 0 {
@@ -77,11 +77,11 @@ func ServiceCommandFunc(_ *cobra.Command, args []string) {
 		key := util.StringJoin([]string{domainProject, env, appID, name}, "/")
 		svc, ok := records[key]
 		if !ok {
-			svc = &ServiceRecord{
+			svc = &Record{
 				Service: model.Service{
 					DomainProject: domainProject,
 					Environment:   env,
-					AppId:         appID,
+					AppID:         appID,
 					ServiceName:   name,
 				},
 			}
@@ -93,7 +93,7 @@ func ServiceCommandFunc(_ *cobra.Command, args []string) {
 		svc.UpdateTimestamp(ms.Value.Timestamp)
 	}
 
-	sp := &ServicePrinter{Records: records}
+	sp := &Printer{Records: records}
 	sp.SetOutputFormat(get.Output, get.AllDomains)
 	writer.PrintTable(sp)
 }
