@@ -18,24 +18,18 @@
 set -x
 set +e
 db_name=$1
-docker rm -f $db_name
+docker rm -f "$db_name"
 set -e
 
 ut_for_dir() {
     local name=$1
-    echo "${green}Running  UT for Service-Center $name${reset}"
-    bash -x ./scripts/ut.sh $name
-}
-
-ut_for_file() {
-    local name=$1
-    echo "${green}Running UT for Service-Center $name${reset}"
-    bash -x ./scripts/ut_file.sh $name
+    echo "${green}Running  UT for Service-Center, skip package $name${reset}"
+    bash -x ./scripts/ut.sh "$name"
 }
 
 echo "${green}Starting Unit Testing for Service Center${reset}"
 
-if [ ${db_name} == "etcd" ];then
+if [ "${db_name}" == "etcd" ];then
   echo "${green}Starting etcd in docker${reset}"
   docker run -d -v /usr/share/ca-certificates/:/etc/ssl/certs -p 40010:40010 -p 23800:23800 -p 2379:2379 --name etcd quay.io/coreos/etcd etcd -name etcd0 -advertise-client-urls http://127.0.0.1:2379,http://127.0.0.1:40010 -listen-client-urls http://0.0.0.0:2379,http://0.0.0.0:40010 -initial-advertise-peer-urls http://127.0.0.1:23800 -listen-peer-urls http://0.0.0.0:23800 -initial-cluster-token etcd-cluster-1 -initial-cluster etcd0=http://127.0.0.1:23800 -initial-cluster-state new
   while ! nc -z 127.0.0.1 2379; do
@@ -59,17 +53,10 @@ echo "${green}Preparing the env for UT....${reset}"
 
 if [ ${db_name} == "etcd" ];then
   export TEST_MODE=etcd
-  [ $? == 0 ] && ut_for_file datasource
-  [ $? == 0 ] && ut_for_dir datasource/schema
-  [ $? == 0 ] && ut_for_dir datasource/etcd
-  [ $? == 0 ] && ut_for_dir pkg
-  [ $? == 0 ] && ut_for_dir server
-  [ $? == 0 ] && ut_for_dir scctl
+  [ $? == 0 ] && ut_for_dir 'datasource/mongo'
 elif [ ${db_name} == "mongo" ];then
   export TEST_MODE=mongo
-  [ $? == 0 ] && ut_for_file datasource
-  [ $? == 0 ] && ut_for_dir datasource/mongo
-  [ $? == 0 ] && ut_for_dir server
+  [ $? == 0 ] && ut_for_dir 'datasource/etcd\|datasource/schema'
 else
   echo "${db_name} non-existent"
 	exit 1
@@ -88,4 +75,4 @@ fi
 echo "${green}Service-Center finished${reset}"
 
 echo "${green}Cleaning up the $db_name docker container${reset}"
-docker rm -f $db_name
+docker rm -f "$db_name"
