@@ -20,16 +20,16 @@ package config
 import (
 	"encoding/json"
 	"fmt"
+	"os"
 	"path/filepath"
 	"runtime"
 	"time"
 
-	"github.com/go-chassis/go-archaius"
-
 	"github.com/apache/servicecomb-service-center/pkg/log"
 	"github.com/apache/servicecomb-service-center/pkg/plugin"
 	"github.com/apache/servicecomb-service-center/pkg/util"
 	"github.com/apache/servicecomb-service-center/version"
+	"github.com/go-chassis/go-archaius"
 )
 
 const (
@@ -43,42 +43,42 @@ var (
 	App = &AppConfig{Server: Server}
 )
 
-//GetProfile return active profile
+// GetProfile return active profile
 func GetProfile() *ServerConfig {
 	return App.Server
 }
 
-//GetGov return governance configs
+// GetGov return governance configs
 func GetGov() *Gov {
 	return App.Gov
 }
 
-//GetServer return the http server configs
+// GetServer return the http server configs
 func GetServer() ServerConfigDetail {
 	return App.Server.Config
 }
 
-//GetSSL return the ssl configs
+// GetSSL return the ssl configs
 func GetSSL() ServerConfigDetail {
 	return App.Server.Config
 }
 
-//GetLog return the log configs
+// GetLog return the log configs
 func GetLog() ServerConfigDetail {
 	return App.Server.Config
 }
 
-//GetRegistry return the registry configs
+// GetRegistry return the registry configs
 func GetRegistry() ServerConfigDetail {
 	return App.Server.Config
 }
 
-//GetPlugin return the plugin configs
+// GetPlugin return the plugin configs
 func GetPlugin() ServerConfigDetail {
 	return App.Server.Config
 }
 
-//GetRBAC return the rbac configs
+// GetRBAC return the rbac configs
 func GetRBAC() ServerConfigDetail {
 	return App.Server.Config
 }
@@ -93,7 +93,7 @@ func Init() {
 
 	err = archaius.AddFile(filepath.Join(util.GetAppRoot(), "conf", "app.yaml"))
 	if err != nil {
-		log.Warn(fmt.Sprintf("can not add config file source, error: %s", err))
+		log.Warn(fmt.Sprintf("can not add app config file source, error: %s", err))
 	}
 
 	err = Reload()
@@ -106,17 +106,24 @@ func Init() {
 	version.Ver().Log()
 }
 
-//Reload reload the all configurations
+// Reload reload the all configurations
 func Reload() error {
 	err := archaius.UnmarshalConfig(App)
 	if err != nil {
 		return err
 	}
+
 	*Server = loadServerConfig()
 	if GetLog().LogLevel == "DEBUG" {
 		body, _ := json.MarshalIndent(archaius.GetConfigs(), "", "  ")
 		log.Debug(fmt.Sprintf("finish to reload configurations\n%s", body))
 	}
+
+	grcCfg := loadGrcConfig()
+	if grcCfg != nil {
+		App.Gov.MatchGroup = grcCfg.MatchGroup
+		App.Gov.Policies = grcCfg.Policies
+	}
 	return nil
 }
 
@@ -187,3 +194,23 @@ func setCPUs() {
 	runtime.GOMAXPROCS(cores)
 	log.Info(fmt.Sprintf("service center is running simultaneously with %d CPU cores", cores))
 }
+
+func loadGrcConfig() *Gov {
+	grcFile := filepath.Join(util.GetAppRoot(), "conf", "grc.json")
+	bytes, err := os.ReadFile(grcFile)
+	if err != nil {
+		log.Warn(fmt.Sprintf("can not add grc config file source, error: %s", err))
+		return nil
+	}
+	var policies AppConfig
+	err = json.Unmarshal(bytes, &policies)
+	if err != nil {
+		log.Error("unmarshal grc config failed", err)
+		return nil
+	}
+	if policies.Gov == nil {
+		log.Warn("no grc config load")
+		return nil
+	}
+	return policies.Gov
+}
