@@ -19,6 +19,7 @@ package cors
 
 import (
 	"errors"
+	"fmt"
 	"net/http"
 
 	"github.com/apache/servicecomb-service-center/pkg/log"
@@ -37,7 +38,7 @@ func init() {
 func Intercept(w http.ResponseWriter, r *http.Request) (err error) {
 	CORS.HandlerFunc(w, r)
 	if r.Method == "OPTIONS" {
-		log.Debugf("identify the current request is a CORS, url: %s", r.RequestURI)
+		log.Debug(fmt.Sprintf("identify the current request is a CORS, url: %s", r.RequestURI))
 		err = errors.New("Handle the preflight request")
 	}
 	return
