@@ -27,9 +27,6 @@ const AUTH plugin.Kind = "auth"
 
 type Authenticate interface {
 	Identify(r *http.Request) error
-	// ResourceScopes return the scope parsed from request
-	// return nil mean apply all resources
-	ResourceScopes(r *http.Request) *ResourceScope
 }
 
 func Auth() Authenticate {
@@ -39,7 +36,3 @@ func Auth() Authenticate {
 func Identify(r *http.Request) error {
 	return Auth().Identify(r)
 }
-
-func ResourceScopes(r *http.Request) *ResourceScope {
-	return Auth().ResourceScopes(r)
-}
