@@ -27,11 +27,6 @@ func init() {
 
 func initRouter() {
 	roa.RegisterServant(&MainService{})
-	roa.RegisterServant(&MicroServiceService{})
-	roa.RegisterServant(&SchemaService{})
 	roa.RegisterServant(&DependencyService{})
-	roa.RegisterServant(&TagService{})
-	roa.RegisterServant(&RuleService{})
-	roa.RegisterServant(&MicroServiceInstanceService{})
 	roa.RegisterServant(&WatchService{})
 }
