@@ -22,6 +22,13 @@ import (
 	"crypto/tls"
 	"os"
 
+	"github.com/apache/servicecomb-service-center/server/middleware"
+	"github.com/apache/servicecomb-service-center/server/resource/disco"
+	"github.com/gofiber/fiber/v2"
+
+	"github.com/go-chassis/go-chassis/v2"
+	chassisServer "github.com/go-chassis/go-chassis/v2/core/server"
+
 	"github.com/apache/servicecomb-service-center/datasource"
 	nf "github.com/apache/servicecomb-service-center/pkg/event"
 	"github.com/apache/servicecomb-service-center/pkg/log"
@@ -32,19 +39,18 @@ import (
 	"github.com/apache/servicecomb-service-center/server/config"
 	"github.com/apache/servicecomb-service-center/server/event"
 	"github.com/apache/servicecomb-service-center/server/plugin/security/tlsconf"
-	"github.com/apache/servicecomb-service-center/server/service/gov"
+	"github.com/apache/servicecomb-service-center/server/service/grc"
 	"github.com/apache/servicecomb-service-center/server/service/rbac"
 	"github.com/go-chassis/foundation/gopool"
-	"github.com/little-cui/etcdadpt"
 )
 
-var server ServiceCenterServer
+var sc ServiceCenterServer
 
 func Run() {
 	if err := command.ParseConfig(os.Args); err != nil {
 		log.Fatal(err.Error(), err)
 	}
-	server.Run()
+	sc.Run()
 }
 
 type endpoint struct {
@@ -63,11 +69,38 @@ func (s *ServiceCenterServer) Run() {
 
 	s.startServices()
 
+	s.startChassis()
+
 	signal.RegisterListener()
 
 	s.waitForQuit()
 }
 
+func (s *ServiceCenterServer) startChassis() {
+	go func() {
+		mask := make([]string, 0)
+		if !config.GetBool("server.turbo", false) {
+			log.Info("turbo is disabled")
+			mask = append(mask, "rest")
+		} else {
+			app := fiber.New(fiber.Config{})
+
+			app.Use(middleware.PrepareContextFor)
+
+			app.Post("/v4/:project/registry/microservices/:serviceId/instances",
+				disco.FiberRegisterInstance)
+			app.Put("/v4/:project/registry/microservices/:serviceId/instances/:instanceId/heartbeat",
+				disco.FiberSendHeartbeat)
+			app.Get("/v4/:project/registry/instances", disco.FiberFindInstances)
+			chassis.RegisterSchema("rest", app)
+			log.Info("turbo is enabled")
+		}
+		if err := chassis.Run(chassisServer.WithServerMask(mask...)); err != nil {
+			log.Warn(err.Error())
+		}
+	}()
+}
+
 func (s *ServiceCenterServer) waitForQuit() {
 	err := <-s.APIServer.Err()
 	if err != nil {
@@ -88,8 +121,8 @@ func (s *ServiceCenterServer) initialize() {
 }
 
 func (s *ServiceCenterServer) initEndpoints() {
-	s.Endpoint.Host = config.GetString("server.host", "", config.WithStandby("httpaddr"))
-	s.Endpoint.Port = config.GetString("server.port", "", config.WithStandby("httpport"))
+	s.Endpoint.Host = config.GetString("server.host", "127.0.0.1", config.WithStandby("httpaddr"))
+	s.Endpoint.Port = config.GetString("server.port", "30100", config.WithStandby("httpport"))
 }
 
 func (s *ServiceCenterServer) initDatasource() {
@@ -100,30 +133,27 @@ func (s *ServiceCenterServer) initDatasource() {
 		log.Fatal("get datasource tlsConfig failed", err)
 	}
 	if err := datasource.Init(datasource.Options{
-		Config: etcdadpt.Config{
-			Kind:       kind,
-			Logger:     log.Logger,
-			SslEnabled: config.GetSSL().SslEnabled,
-			TLSConfig:  tlsConfig,
-			ConnectedFunc: func() {
-				err := alarm.Clear(alarm.IDBackendConnectionRefuse)
-				if err != nil {
-					log.Error("", err)
-				}
-			},
-			ErrorFunc: func(err error) {
-				if err == nil {
-					return
-				}
-				err = alarm.Raise(alarm.IDBackendConnectionRefuse, alarm.AdditionalContext("%v", err))
-				if err != nil {
-					log.Error("", err)
-				}
-			},
+		Kind:       kind,
+		Logger:     log.Logger,
+		SslEnabled: config.GetSSL().SslEnabled,
+		TLSConfig:  tlsConfig,
+		ConnectedFunc: func() {
+			err := alarm.Clear(alarm.IDBackendConnectionRefuse)
+			if err != nil {
+				log.Error("", err)
+			}
 		},
-		EnableCache:        config.GetRegistry().EnableCache,
-		InstanceTTL:        config.GetRegistry().InstanceTTL,
-		InstanceProperties: config.GetStringMap("registry.instance.properties"),
+		ErrorFunc: func(err error) {
+			if err == nil {
+				return
+			}
+			err = alarm.Raise(alarm.IDBackendConnectionRefuse, alarm.AdditionalContext("%v", err))
+			if err != nil {
+				log.Error("", err)
+			}
+		},
+		EnableCache: config.GetRegistry().EnableCache,
+		InstanceTTL: config.GetRegistry().InstanceTTL,
 	}); err != nil {
 		log.Fatal("init datasource failed", err)
 	}
@@ -163,10 +193,10 @@ func (s *ServiceCenterServer) startServices() {
 	// notifications
 	s.eventCenter.Start()
 
-	// load server plugins
+	// load sc plugins
 	plugin.LoadPlugins()
 	rbac.Init()
-	if err := gov.Init(); err != nil {
+	if err := grc.Init(); err != nil {
 		log.Fatal("init gov failed", err)
 	}
 	// check version
@@ -180,7 +210,7 @@ func (s *ServiceCenterServer) startServices() {
 }
 
 func (s *ServiceCenterServer) startAPIService() {
-	s.APIServer.Listen(s.Endpoint.Host, s.Endpoint.Port)
+	s.APIServer.SetHostPort(s.Endpoint.Host, s.Endpoint.Port)
 	s.APIServer.Start()
 }
 
