@@ -107,6 +107,7 @@ func populateInstanceDefaultValue(ctx context.Context, instance *pb.MicroService
 
 	microservice, err := GetService(ctx, &pb.GetServiceRequest{ServiceId: instance.ServiceId})
 	if err != nil {
+		log.Error("can not get service:"+instance.ServiceId, err)
 		return pb.NewError(pb.ErrServiceNotExists, "Invalid 'serviceID' in request body.")
 	}
 	instance.Version = microservice.Version
@@ -484,3 +485,8 @@ func InstanceUsage(ctx context.Context, request *pb.GetServiceCountRequest) (int
 	}
 	return resp.Count, nil
 }
+
+func UpdateManyInstanceStatus(ctx context.Context, match *datasource.MatchPolicy, status string) error {
+	err := datasource.GetMetadataManager().UpdateManyInstanceStatus(ctx, match, status)
+	return err
+}
