@@ -20,11 +20,16 @@ package rbac
 import (
 	"context"
 	"errors"
+	"net/http"
+
 	"github.com/apache/servicecomb-service-center/pkg/util"
+	"github.com/apache/servicecomb-service-center/server/service/rbac/token"
 	rbacmodel "github.com/go-chassis/cari/rbac"
 )
 
-const CtxRequestClaims util.CtxKey = "_request_claims"
+const (
+	CtxRequestClaims util.CtxKey = "_request_claims"
+)
 
 func UserFromContext(ctx context.Context) string {
 	m, ok := ctx.Value(CtxRequestClaims).(map[string]interface{})
@@ -45,3 +50,12 @@ func AccountFromContext(ctx context.Context) (*rbacmodel.Account, error) {
 	}
 	return rbacmodel.GetAccount(m)
 }
+
+func SignRequest(req *http.Request) error {
+	auth := token.FromContext(req.Context())
+	if auth == "" {
+		return nil
+	}
+	req.Header.Set("Authorization", "Bearer "+auth)
+	return nil
+}
