@@ -21,7 +21,7 @@ import (
 	"context"
 	"crypto/rsa"
 	"errors"
-	"io/ioutil"
+	"os"
 
 	"github.com/go-chassis/cari/pkg/errsvc"
 	"github.com/go-chassis/cari/rbac"
@@ -44,9 +44,12 @@ var (
 	ErrNoPermChangeAccount  = errors.New("can not change other account password")
 	ErrWrongPassword        = errors.New("current pwd is wrong")
 	ErrSamePassword         = errors.New("the password can not be same as old one")
+	ErrNoPrivateKey         = errors.New("read private key failed")
+
+	privateKey *rsa.PrivateKey
 )
 
-//Init decide whether enable rbac function and save the build-in roles to db
+// Init decide whether enable rbac function and save the build-in roles to db
 func Init() {
 	if !Enabled() {
 		log.Info("rbac is disabled")
@@ -57,6 +60,7 @@ func Init() {
 	if err != nil {
 		log.Fatal("can not enable auth module", err)
 	}
+	migrateOldRoles()
 	// build-in role init
 	initBuildInRole()
 	initBuildInAccount()
@@ -87,28 +91,39 @@ func initBuildInAccount() {
 	}
 }
 
-//read key to memory
+// read key to memory
 func readPrivateKey() {
 	pf := config.GetString("rbac.privateKeyFile", "", config.WithStandby("rbac_rsa_private_key_file"))
 	// 打开文件
-	data, err := ioutil.ReadFile(pf)
+	data, err := os.ReadFile(pf)
 	if err != nil {
 		log.Fatal("can not read private key", err)
 		return
 	}
-	err = archaius.Set("rbac_private_key", string(data))
+	content := string(data)
+	err = archaius.Set("rbac_private_key", content)
 	if err != nil {
 		log.Fatal("can not init rbac", err)
 		return
 	}
+	privateKeyContent, err := cipher.Decrypt(content)
+	if err != nil {
+		log.Warn("cipher fallback: " + err.Error())
+		privateKeyContent = content
+	}
+	privateKey, err = secret.ParseRSAPrivateKey(privateKeyContent)
+	if err != nil {
+		log.Error("can not parse private key", err)
+		return
+	}
 	log.Info("read private key success")
 }
 
-//read key to memory
+// read key to memory
 func readPublicKey() {
 	pf := config.GetString("rbac.publicKeyFile", "", config.WithStandby("rbac_rsa_public_key_file"))
 	// 打开文件
-	content, err := ioutil.ReadFile(pf)
+	content, err := os.ReadFile(pf)
 	if err != nil {
 		log.Fatal("can not find public key", err)
 		return
@@ -161,34 +176,20 @@ func Enabled() bool {
 	return config.GetRBAC().EnableRBAC
 }
 
-//PublicKey get public key to verify a token
+// PublicKey get public key to verify a token
 func PublicKey() string {
 	return archaius.GetString("rbac_public_key", "")
 }
 
-//privateKey get decrypted private key to verify a token
-func privateKey() string {
-	ep := archaius.GetString("rbac_private_key", "")
-	p, err := cipher.Decrypt(ep)
-	if err != nil {
-		log.Warn("cipher fallback: " + err.Error())
-		return ep
-	}
-	return p
-}
-
-//GetPrivateKey return rsa key instance
+// GetPrivateKey return rsa key instance
 func GetPrivateKey() (*rsa.PrivateKey, error) {
-	sk := privateKey()
-	p, err := secret.ParseRSAPrivateKey(sk)
-	if err != nil {
-		log.Error("can not get key:", err)
-		return nil, err
+	if privateKey == nil {
+		return nil, ErrNoPrivateKey
 	}
-	return p, nil
+	return privateKey, nil
 }
 
-//MakeBanKey return ban key
+// MakeBanKey return ban key
 func MakeBanKey(name, ip string) string {
 	return name + "::" + ip
 }
