@@ -15,15 +15,13 @@
  * limitations under the License.
  */
 
-//Package test prepare service center required module before UT
+// Package test prepare service center required module before UT
 package test
 
 import (
 	"context"
 	"time"
 
-	_ "github.com/apache/servicecomb-service-center/syncer/init"
-
 	_ "github.com/apache/servicecomb-service-center/server/init"
 
 	_ "github.com/apache/servicecomb-service-center/syncer/bootstrap"
@@ -37,7 +35,6 @@ import (
 	"github.com/go-chassis/cari/db"
 	"github.com/go-chassis/cari/db/config"
 	"github.com/go-chassis/go-archaius"
-	"github.com/little-cui/etcdadpt"
 )
 
 func init() {
@@ -59,9 +56,7 @@ func init() {
 	}
 
 	_ = datasource.Init(datasource.Options{
-		Config: etcdadpt.Config{
-			Kind: kind,
-		},
+		Kind: kind,
 	})
 	_ = metrics.Init(metrics.Options{})
 
